@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# (c) YashDK [yash-dk@github]
+
 
 import os,logging,time,traceback,shutil, asyncio
 from ..core.getVars import get_val
@@ -28,7 +28,7 @@ async def upload_handel(path,message,from_uid,files_dict,job_id=0,force_edit=Fal
     #logging.info("Uploading Now:- {}".format(path))
 
     if os.path.isdir(path):
-        logging.info("Uplaoding the directory:- {}".format(path))
+        logging.info("uploading the directory: {}".format(path))
 
         directory_contents = os.listdir(path)
         directory_contents.sort()
@@ -41,7 +41,7 @@ async def upload_handel(path,message,from_uid,files_dict,job_id=0,force_edit=Fal
         try:
             message = await message.edit("{}\nfound **{}** files for this download.".format(message.text,len(directory_contents)))
         except:
-            torlog.warning("Too much folders will stop the editing of this message")
+        	torlog.warning("too much folders, will stop the editing of this message.")
         
         if not from_in:
             updb.register_upload(message.chat_id,message.id)
@@ -55,7 +55,7 @@ async def upload_handel(path,message,from_uid,files_dict,job_id=0,force_edit=Fal
                 await task.set_original_message(sup_mes)
             
             data = "upcancel {} {} {}".format(message.chat_id,message.id,sup_mes.sender_id)
-            buts = [KeyboardButtonCallback("Cancel upload.",data.encode("UTF-8"))]
+            buts = [KeyboardButtonCallback("cancel upload.",data.encode("UTF-8"))]
             message = await message.edit(buttons=buts)
 
 
@@ -81,13 +81,13 @@ async def upload_handel(path,message,from_uid,files_dict,job_id=0,force_edit=Fal
             if updb.get_cancel_status(message.chat_id,message.id):
                 task.cancel = True
                 await task.set_inactive()
-                await message.edit("`{}` - Canceled By user.".format(message.text),buttons=None)
+                await message.edit("`{}` - canceled by user.".format(message.text),buttons=None)
             else:
                 await message.edit(buttons=None)
             updb.deregister_upload(message.chat_id,message.id)
 
     else:
-        logging.info("Uploading the file:- {}".format(path))
+        logging.info("uploading the file: {}".format(path))
         if os.path.getsize(path) > get_val("TG_UP_LIMIT"):
             # the splitted file will be considered as a single upload ;)
             
@@ -108,11 +108,11 @@ async def upload_handel(path,message,from_uid,files_dict,job_id=0,force_edit=Fal
                 ftype = "unknown"
             
             if ftype == "video":    
-                todel = await message.reply("**file larger then threshold, splitting now. **\n**Processing.....** ```using algo ffmpeg split```") 
+                todel = await message.reply("**file larger then threshold, splitting now. **\n**processing.....** ```using algo ffmpeg split```") 
                 split_dir = await vids_helpers.split_file(path,get_val("TG_UP_LIMIT"))
                 await todel.delete()
             else:
-                todel = await message.reply("**file larger then threshold, splitting now. **\n**Processing.....** ```using algo ffmpeg split```") 
+                todel = await message.reply("**file larger then threshold, splitting now. **\n**processing.....** ```using algo ffmpeg split```")  
                 split_dir = await zip7_utils.split_in_zip(path,get_val("TG_UP_LIMIT"))
                 await todel.delete()
             
@@ -134,7 +134,7 @@ async def upload_handel(path,message,from_uid,files_dict,job_id=0,force_edit=Fal
                     await task.set_original_message(sup_mes)
 
                 data = "upcancel {} {} {}".format(message.chat_id,message.id,sup_mes.sender_id)
-                buts = [KeyboardButtonCallback("Cancel upload.",data.encode("UTF-8"))]
+                buts = [KeyboardButtonCallback("cancel upload.",data.encode("UTF-8"))]
                 await message.edit(buttons=buts)
 
             for file in dircon:
@@ -164,7 +164,7 @@ async def upload_handel(path,message,from_uid,files_dict,job_id=0,force_edit=Fal
                 if updb.get_cancel_status(message.chat_id,message.id):
                     task.cancel = True
                     await task.set_inactive()
-                    await message.edit("`{}` - Canceled By user.".format(message.text),buttons=None)
+                    await message.edit("`{}` - canceled By user.".format(message.text),buttons=None)
                 else:
                     await message.edit(buttons=None)
                 updb.deregister_upload(message.chat_id,message.id)
@@ -186,7 +186,7 @@ async def upload_handel(path,message,from_uid,files_dict,job_id=0,force_edit=Fal
                     await task.set_original_message(sup_mes)
 
                 data = "upcancel {} {} {}".format(message.chat_id,message.id,sup_mes.sender_id)
-                buts = [KeyboardButtonCallback("Cancel upload.",data.encode("UTF-8"))]
+                buts = [KeyboardButtonCallback("cancel upload.",data.encode("UTF-8"))]
                 await message.edit(buttons=buts)
             #print(updb)
             if black_list_exts(path):
@@ -207,7 +207,7 @@ async def upload_handel(path,message,from_uid,files_dict,job_id=0,force_edit=Fal
                 if updb.get_cancel_status(message.chat_id,message.id):
                     task.cancel = True
                     await task.set_inactive()
-                    await message.edit("`{}` - Canceled By user.".format(message.text),buttons=None)
+                    await message.edit("`{}` - canceled By user.".format(message.text),buttons=None)
                 else:
                     await message.edit(buttons=None)
                 updb.deregister_upload(message.chat_id,message.id)
@@ -261,18 +261,18 @@ async def upload_a_file(path,message,force_edit,database=None,thumb_path=None,us
 
     if not force_edit:        
         data = "upcancel {} {} {}".format(message.chat_id,message.id,user_msg.sender_id)
-        buts = [KeyboardButtonCallback("Cancel upload.",data.encode("UTF-8"))]
-        msg = await message.reply("📤 **Uploading:** `{}`".format(file_name),buttons=buts)
+        buts = [KeyboardButtonCallback("cancel upload.",data.encode("UTF-8"))]
+        msg = await message.reply("**uploading:** `{}`".format(file_name),buttons=buts)
 
     else:
         msg = message
 
     uploader_id = None
     if queue is not None:
-        torlog.info(f"Waiting for the worker here for {file_name}")
-        msg = await msg.edit(f"{msg.text}\n⌛ Waiting for a uploaders to get free... ")
+        torlog.info(f"waiting for the worker here for {file_name}")
+        msg = await message.reply("**uploading:** `{}`".format(file_name),buttons=buts)
         uploader_id = await queue.get()
-        torlog.info(f"Waiting over for the worker here for {file_name} aquired worker {uploader_id}")
+        torlog.info(f"waiting over for the worker here for {file_name} acquired worker {uploader_id}")
 
     out_msg = None
     start_time = time.time()
@@ -288,8 +288,8 @@ async def upload_a_file(path,message,force_edit,database=None,thumb_path=None,us
     
     try:
         if get_val("FAST_UPLOAD"):
-            torlog.info("Fast upload is enabled")
-            with open(path,"rb") as filee:
+             torlog.info("fast upload is enabled.")
+        with open(path,"rb") as filee:
                 path = await upload_file(message.client,filee,file_name,
                 lambda c,t: progress(c,t,msg,file_name,start_time,tout,message,database)
                 )
@@ -317,7 +317,7 @@ async def upload_a_file(path,message,force_edit,database=None,thumb_path=None,us
                         thumb = await thumb_manage.get_thumbnail(opath)
                 except:
                     thumb = None
-                    torlog.exception("Error in thumb")
+                    torlog.exception("error in thumbnail.")
                 try:
                     attrs, _ = get_attributes(opath,supports_streaming=True)
                     out_msg = await msg.client.send_file(
@@ -333,7 +333,7 @@ async def upload_a_file(path,message,force_edit,database=None,thumb_path=None,us
                     )
                 except VideoContentTypeInvalidError:
                     attrs, _ = get_attributes(opath,force_document=True)
-                    torlog.warning("Streamable file send failed fallback to document.")
+                    torlog.warning("streamable file send failed, fallback to document.")
                     out_msg = await msg.client.send_file(
                         msg.to_id,
                         file=path,
@@ -346,7 +346,7 @@ async def upload_a_file(path,message,force_edit,database=None,thumb_path=None,us
                         attributes=attrs
                     )
                 except Exception:
-                    torlog.error("Error:- {}".format(traceback.format_exc()))
+                    torlog.error("error: {}".format(traceback.format_exc()))
             elif ftype == "audio" and not force_docs:
                 # not sure about this if
                 attrs, _ = get_attributes(opath)
@@ -390,12 +390,12 @@ async def upload_a_file(path,message,force_edit,database=None,thumb_path=None,us
             torlog.info("canceled upload")
             await msg.edit(f"failed to upload {e}")
         else:
-            torlog.exception("In Tele Upload")
+            torlog.exception("in telegram upload")
             await msg.edit(f"failed to upload {e}")
     finally:
         if queue is not None:
             await queue.put(uploader_id)
-            torlog.info(f"Freed uploader with id {uploader_id}")
+            torlog.info(f"freed uploader with id {uploader_id}")
                 
 
     if out_msg is None:
@@ -422,6 +422,8 @@ async def upload_single_file(path, message, force_edit,database=None,thumb_image
     if not os.path.exists(path):
         return None
     
+    queue = message.client.exqueue
+
     file_name = os.path.basename(path)
     caption_str = ""
     caption_str += "<code>"
@@ -466,15 +468,22 @@ async def upload_single_file(path, message, force_edit,database=None,thumb_image
             if not thumb_image_path:
                 thumb_image_path = None
     #
+    uploader_id = None
     try:
         message_for_progress_display = message
         if not force_edit:
             data = "upcancel {} {} {}".format(message.chat.id,message.message_id,user_msg.sender_id)
-            markup = InlineKeyboardMarkup([[InlineKeyboardButton("Cancel Upload", callback_data=data.encode("UTF-8"))]])
+            markup = InlineKeyboardMarkup([[InlineKeyboardButton("cancel upload.", callback_data=data.encode("UTF-8"))]])
             message_for_progress_display = await message.reply_text(
-                "📤 **Starting upload of** `{}`".format(os.path.basename(path)),
+                "**starting upload of** `{}`".format(os.path.basename(path)),
                 reply_markup=markup
             )
+
+            if queue is not None:
+                torlog.info(f"waiting for the worker here for {file_name}")
+                message_for_progress_display = await message_for_progress_display.edit(f"{message_for_progress_display.text}\nwaiting in uploading queue.. ")
+                uploader_id = await queue.get()
+                torlog.info(f"waiting over for the worker here for {file_name} acquired worker {uploader_id}")
         
         if ftype == "video" and not force_docs:
             metadata = extractMetadata(createParser(path))
@@ -482,8 +491,8 @@ async def upload_single_file(path, message, force_edit,database=None,thumb_image
             if metadata.has("duration"):
                 duration = metadata.get('duration').seconds
             #
-            width = 0
-            height = 0
+            width = 1280
+            height = 720
             if thumb_image_path is None:
                 thumb_image_path = await thumb_manage.get_thumbnail(path)
                 # get the correct width, height, and duration for videos greater than 10MB
@@ -522,7 +531,7 @@ async def upload_single_file(path, message, force_edit,database=None,thumb_image
                     # reply_to_message_id=message.reply_to_message.message_id,
                     progress=progress_for_pyrogram,
                     progress_args=(
-                        "trying to upload...",
+                        f"uploading {os.path.basename(path)}",
                         message_for_progress_display,
                         start_time,
                         tout,
@@ -577,7 +586,7 @@ async def upload_single_file(path, message, force_edit,database=None,thumb_image
                     # reply_to_message_id=message.reply_to_message.message_id,
                     progress=progress_for_pyrogram,
                     progress_args=(
-                        "trying to upload...",
+                        f"uploading {os.path.basename(path)}",
                         message_for_progress_display,
                         start_time,
                         tout,
@@ -618,7 +627,7 @@ async def upload_single_file(path, message, force_edit,database=None,thumb_image
                     progress=progress_for_pyrogram,
                     caption=caption_str,
                     progress_args=(
-                        "trying to upload...",
+                        f"💠 Uploading {os.path.basename(path)}",
                         message_for_progress_display,
                         start_time,
                         tout,
@@ -640,12 +649,16 @@ async def upload_single_file(path, message, force_edit,database=None,thumb_image
             try:
                 await message_for_progress_display.edit(f"failed to upload {e}")
             except:pass
-            torlog.exception("in pyro upload")
+            torlog.exception("in pyrogram upload")
     else:
         if message.message_id != message_for_progress_display.message_id:
             await message_for_progress_display.delete()
+    finally:
+        if queue is not None and uploader_id is not None:
+            await queue.put(uploader_id)
+            torlog.info(f"freed uploader with id {uploader_id}")
     #os.remove(path)
     if sent_message is None:
         return None
     sent_message = await thonmsg.client.get_messages(sent_message.chat.id, ids=sent_message.message_id)
-    return sent_message
\ No newline at end of file
+    return sent_message
